document.addEventListener('DOMContentLoaded', function() {
    var el = document.getElementById('text');
    (function getWebOSModel() {
        //gets the device's model
        var custom = new Custom();
        custom.Signage.getwebOSVersion(
            function successCallback(successObject) {
                const ver = successObject.webOSVersion;
                console.log('webOS Signage version: ' + successObject.webOSVersion);
                //do actions based on device model
                if (ver === '1.0' || ver === '2.0') {
                    handleWebOS12();
                } else {
                    handleWebOS34();
                }
            },
            function failureCallback(failureObject) {
                console.error('[' + failureObject.errorCode + ']' + failureObject.errorText);
            }
        );
    })();

    function handleWebOS12() {
        getNetworkInfo(function(err2, data2) {
            if (err2) {
                handleWebOS12();
                return
            }
            fetchLatest(function(err, data) {
                if (err) {
                    handleWebOS12();
                    return
                }
                var configuration = new Configuration();
                //sets up debug mode here
                configuration.debug(
                    function debugSuccessCb() {
                        console.log('Debug Mode Enabled')
                    },
                    function debugFailureCb() {
                        console.log('Failed to set Debug Mode');
                    }, {
                        enabled: true
                    }
                );
                var latest = window.latestProdVersion;
                var options = {};
                options.serverIp = "0.0.0.0";
                options.serverPort = 80;
                options.secureConnection = false;
                options.appLaunchMode = Configuration.AppMode.LOCAL;
                // options.appType = Configuration.AppMode.ZIP;
                options.fqdnMode = true;
                options.fqdnAddr = "http://r.ommasign.com/" + latest + "/weboss.zip";
                //do things with declared vars
                configuration.setServerProperty(
                    function() {
                        console.log("Successfuly initiated");
                        el.textContent = "Gathering information to install OMMA app...";
                        setTimeout(function() {
                            upgradeZIPApplication();
                        }, 3000);
                    },
                    function() {
                        console.log("Initiation failed");
                        console.error('[' + failureObject.errorCode + ']' + failureObject.errorText);
                    },
                    options
                );

                function upgradeZIPApplication() {
                    el.textContent = "Do not turn off your device. Installing App in 5 seconds..."
                    var storage = new Storage();
                    var successCb = function() {
                        el.textContent = "App installation successful. Restarting in 5 seconds...";
                        setTimeout(function(data) {
                            handleRestart()
                        }, 5000);
                    };
                    var failureCb = function(cbObject) {
                        var errorCode = cbObject.errorCode;
                        var errorText = cbObject.errorText;
                        console.log(" Error Code [" + errorCode + "]: " + errorText);
                    };
                    setTimeout(function() {
                        storage.upgradeApplication(successCb, failureCb, {
                            to: Storage.AppMode.LOCAL,
                            recovery: false
                        });
                    }, 5000);

                }
            });
        });
    }

    function handleWebOS34() {
        el.innerHTML = "You have installed OMMA app in <strong>ZIP</strong> format which is not recommended.\nPlease reinstall by changing the last part of installation link <strong>from ZIP to IPK</strong>, and selecting <strong>IPK</strong> as application type."
    }


    ////// UTILS


    function getNetworkInfo(cb) {
        var elem = document.getElementById('internet_conn');

        function successCb(cbObject) {
            elem.textContent = "Connected to internet.";
            window._internetConnection = true;
            cb(null, cbObject);
        };

        function failureCb(cbObject) {
            elem.textContent = "Failed to connect to internet."
            var errorCode = cbObject.errorCode;
            var errorText = cbObject.errorText;
            console.log('Error Code [' + errorCode + ']: ' + errorText);
            cb(cbObject);
        };

        var deviceInfo = new DeviceInfo();
        deviceInfo.getNetworkInfo(successCb, failureCb);
    }


    function fetchLatest(cb) {
        var platforms;
        var xhr = new XMLHttpRequest();
        xhr.open("GET", "http://r.ommasign.com/version.json");
        xhr.send();
        xhr.onload = function() {
            var res = xhr.response;
            console.log(res);
            console.log('fetched data');
            try {
                platforms = JSON.parse(res);
                console.log('latest for test env is: ', platforms.prod.weboss.version);
                window.latestTestVersion = platforms.test.weboss.version;
                window.latestProdVersion = platforms.prod.weboss.version;
                cb(null, platforms);
            } catch (e) {
                el.textContent = e;
                cb(e);
            }
            console.log("platforms are: ", platforms);
        }
        xhr.onerror = function() {
            console.log("an error has occured")
        }
    }

    function handleRestart() {
        function successCb() {}

        function failureCb(cbObject) {
            var errorCode = cbObject.errorCode;
            var errorText = cbObject.errorText;
            console.log("Error Code [" + errorCode + "]: " + errorText);
        }
        var power = new Power();
        power.executePowerCommand(successCb, failureCb, {
            powerCommand: Power.PowerCommand.REBOOT
        });
    }
});